#' mx.api: Minimal Matrix Client-Server API
#'
#' Base-R bindings for the Matrix Client-Server HTTP API, suitable for
#' talking to a Synapse homeserver. Two dependencies: curl and jsonlite.
#' End-to-end encryption is out of scope; use unencrypted rooms or a
#' separate crypto package.
#'
#' @name mx.api-package
#' @aliases mx.api
"_PACKAGE"

